"""
conf for :mod:`opensearch_xml` application.

:creationdate:  12/06/2024 09:31
:moduleauthor: François GUÉRIN <fguerin@ville-tourcoing.fr>
:modulename: opensearch_xml.conf
"""

import logging

from appconf import AppConf

__author__ = "fguerin"
logger = logging.getLogger(__name__)


class OpenSearchXMLAppConf(AppConf):
    """App configuration for :mod:`opensearch_xml`."""

    CONTACT_EMAIL: str = ""
    SHORT_NAME: str = ""
    DESCRIPTION: str = ""
    FAVICON_WIDTH: int = 16
    FAVICON_HEIGHT: int = 16
    FAVICON_TYPE: str = "image/x-icon"
    FAVICON_FILE: str = "favicon.ico"
    SEARCH_URL: str = "search"
    SEARCH_QUERYSTRING: str = "q="
    INPUT_ENCODING: str = "UTF-8"

    class Meta:
        """Metaclass for `opensearch_xml.conf.OpenSearchXMLAppConf`."""

        prefix = "opensearch_xml"



"""
apps for :mod:`opensearch_xml` application.

:creationdate:  13/06/2024 08:20
:moduleauthor: François GUÉRIN <fguerin@ville-tourcoing.fr>
:modulename: opensearch_xml.apps
"""

import logging

from django.apps import AppConfig

__author__ = "fguerin"
logger = logging.getLogger(__name__)


class OpenSearchXmlAppConfig(AppConfig):
    """:mod:`opensearch_xml` app configuration."""

    name = "opensearch_xml"

    def ready(self) -> None:
        """Perform some operations when application is ready."""
        super().ready()
        logger.debug("%s::ready()", self.__class__.__name__)
        from opensearch_xml import conf  # noqa



"""
urls for :mod:`opensearch_xml` application.

:creationdate:  13/06/2024 08:40
:moduleauthor: François GUÉRIN <fguerin@ville-tourcoing.fr>
:modulename: opensearch_xml.urls
"""

import logging

from django.urls import path

from opensearch_xml import views

__author__ = "fguerin"
logger = logging.getLogger(__name__)

app_name = "opensearch_xml"
urlpatterns = [
    path("opensearch.xml", views.opensearch_xml, name="xml"),
]



"""
views for :mod:`opensearch_xml` application.

:creationdate:  13/06/2024 08:26
:moduleauthor: François GUÉRIN <fguerin@ville-tourcoing.fr>
:modulename: opensearch_xml.views
"""

import logging
from typing import Any

from django.conf import settings
from django.http import HttpResponse
from django.http.request import HttpRequest
from django.shortcuts import resolve_url
from django.template.loader import render_to_string

__author__ = "fguerin"
logger = logging.getLogger(__name__)


def opensearch_xml(request: HttpRequest) -> HttpResponse:
    """Render OpenSearch XML page."""
    if settings.STATIC_URL.startswith("http") or settings.STATIC_URL.startswith("//"):
        _favicon_file = settings.STATIC_URL + settings.OPENSEARCH_XML_FAVICON_FILE
    else:
        _favicon_file = request.build_absolute_uri(settings.STATIC_URL + settings.OPENSEARCH_XML_FAVICON_FILE)
    context: dict[str, Any] = {
        "CONTACT_EMAIL": settings.OPENSEARCH_XML_CONTACT_EMAIL,
        "SHORT_NAME": settings.OPENSEARCH_XML_SHORT_NAME,
        "DESCRIPTION": settings.OPENSEARCH_XML_DESCRIPTION,
        "FAVICON_WIDTH": settings.OPENSEARCH_XML_FAVICON_WIDTH,
        "FAVICON_HEIGHT": settings.OPENSEARCH_XML_FAVICON_HEIGHT,
        "FAVICON_TYPE": settings.OPENSEARCH_XML_FAVICON_TYPE,
        "FAVICON_FILE": _favicon_file,
        "URL": "{url}?{querystring}{{searchTerms}}".format(  # noqa: FS002
            **{
                "url": request.build_absolute_uri(resolve_url(to=settings.OPENSEARCH_XML_SEARCH_URL)),
                "querystring": settings.OPENSEARCH_XML_SEARCH_QUERYSTRING,
            }
        ),
        "INPUT_ENCODING": settings.OPENSEARCH_XML_INPUT_ENCODING.upper(),
    }
    output = render_to_string("opensearch_xml/opensearch.xml", context)
    logger.debug("opensearch_xml()\n%s", output)
    if settings.DEBUG:
        from xml.dom.minidom import parseString  # noqa: S408

        temp = parseString(output)  # noqa: S318
        logger.debug("opensearch_xml()\n%s", temp.toprettyxml())
    return HttpResponse(
        output,
        content_type="application/opensearchdescription+xml",
        status=200,
    )



"""
opensearch_xml_tags_tags for the :mod:`opensearch_xml` application.

:creationdate: 12/06/2024
:moduleauthor: François GUÉRIN <fguerin@ville-tourcoing.fr>
:modulename: opensearch_xml.templatetags.opensearch_xml_tags_tags
"""

import logging
from typing import Any

from django import template
from django.conf import settings

logger = logging.getLogger(__name__)
register = template.Library()


@register.inclusion_tag("opensearch_xml/tags/opensearch_xml_meta.html")
def opensearch_xml_meta() -> dict[str, Any]:
    """Return OpenSearch metadata."""
    return {
        "debug": settings.DEBUG,
        "DESCRIPTION": settings.OPENSEARCH_XML_DESCRIPTION,
    }


@register.inclusion_tag("opensearch_xml/tags/opensearch_xml_meta.html")
def opensearch_meta() -> dict[str, Any]:
    """
    Return OpenSearch metadata.

    .. note:: Alias for ``opensearch_xml_meta``.
    """
    return opensearch_xml_meta()
